# frozen_string_literal: true

require 'pathname'

# TODO: For extra boilerplate's sake (!), convert to a class that
# renders as symlink
#
# TODO: Use hardlinks? There won't be a "canonical" file because they
# all will be the same file, but the site would work on filesystems that
# don't support symlinks.
Jekyll::Hooks.register :site, :post_write do |site|
  # Traverse all files that could contain alternate-permalinks
  [site.pages, site.documents].flatten.each do |page|
    # Get a pathname for the file
    path = Pathname.new page.destination site.dest

    # Create a symlink for each alternate permalink
    page.data['alternate-permalinks']&.each do |alt|
      alt = Jekyll::PathManager.join(alt, 'index.html') if alt.end_with? '/'

      alt_path = Pathname.new site.in_dest_dir(alt)

      if File.exist? alt_path
        Jekyll.logger.warn "#{alt_path} already exists, skipping"
      else
        Jekyll.logger.debug "Symlink from #{path.relative_path_from(alt_path.dirname)} to #{alt}"

        FileUtils.mkdir_p(alt_path.dirname)
        File.symlink path.relative_path_from(alt_path.dirname), alt_path
      end
    end
  end
end
